"""
API-to-MCP Generator

A Python library to automatically convert any OpenAPI v2/v3 specification 
into a Model Context Protocol (MCP) server.
"""

__version__ = "0.1.2"
__author__ = "Sriram Krishna"
__license__ = "MPL-2.0"
